@@ -11,23 +11,22 @@ client.on('ready', () => {
   console.log('discord.js client ready');
 });
 
-client.on('message', message => {
+client.on('message', async message => {
   if (!message.content.startsWith('++play')) return;
 
   console.log('Got a song request!');
-  const voiceChannel = message.member.voiceChannel;
+  const voiceChannel = message.member.voice.channel;
   if (!voiceChannel) {
     message.reply('Please be in a voice channel first!');
     return;
   }
-  voiceChannel.join()
-    .then(connection => {
-      const stream = ytdl(url, { filter: 'audioonly' });
-      const dispatcher = connection.playStream(stream);
-      dispatcher.on('end', () => {
-        voiceChannel.leave();
-      });
-    });
+  const connection = await voiceChannel.join();
+  // Disabling chunking is recommended in Discord bots
+  const stream = ytdl(url, { filter: 'audioonly', dlChunkSize: 0 });
+  const dispatcher = connection.play(stream);
+  dispatcher.on('speaking', speaking => {
+    if (!speaking) voiceChannel.leave();
+  });
 });
 
 client.login(clientToken);
