@@ -1,8 +1,8 @@
 // A cache that expires.
 module.exports = class Cache extends Map {
-  constructor() {
+  constructor(timeout = 1000) {
     super();
-    this.timeout = 1000;
+    this.timeout = timeout;
   }
   set(key, value) {
     super.set(key, {
@@ -17,6 +17,15 @@ module.exports = class Cache extends Map {
     }
     return null;
   }
+  async getOrSet(key, fn) {
+    if (this.has(key)) {
+      return this.get(key);
+    } else {
+      let value = await fn();
+      this.set(key, value);
+      return value;
+    }
+  }
   delete(key) {
     let entry = super.get(key);
     if (entry) {
